@@ -49,7 +49,7 @@ class DetectorHttpConnector:
                                             is_inner_request=is_inner_request,
                                             )
 
-        return [dict_to_dataclass(settings, self.detector_settings_type) for settings in answer["result"]]
+        return [dict_to_dataclass(settings, self.detector_settings_type) for settings in answer]
 
     async def set_settings(self, detector_settings: DetectorSettings,
                            token: Optional[str] = None, is_inner_request: bool = False) -> DetectorSettings:
@@ -62,7 +62,7 @@ class DetectorHttpConnector:
                                             is_inner_request=is_inner_request,
                                             )
 
-        return dict_to_dataclass(answer["result"], self.detector_settings_type)
+        return dict_to_dataclass(answer, self.detector_settings_type)
 
     async def autotune_settings(self, rtsp_url: str, miss_decision_timerange: Timerange,
                                 token: Optional[str] = None, is_inner_request: bool = False) -> DetectorSettings:
@@ -78,7 +78,7 @@ class DetectorHttpConnector:
                                             is_inner_request=is_inner_request,
                                             )
 
-        return dict_to_dataclass(answer["result"], self.detector_settings_type)
+        return dict_to_dataclass(answer, self.detector_settings_type)
 
     async def _auth_post_json(self, url: str, payload: dict, headers: dict | None = None,
                               token: str | None = None, is_inner_request: bool = False) -> dict:
