@@ -12,6 +12,7 @@ import json
 import logging
 
 from aiokafka import ConsumerRecord
+from async_tools import AsyncInitable, AsyncDeinitable
 from kafka_tools.abstract_buffer import AbstractBuffer
 from kafka_tools.deserializer import RecordDeserializer, JsonDeserializer, AbstractDeserializer
 
@@ -41,7 +42,7 @@ class DetectorAnalyzeResult:
 AnalyzeResultCallback = Callable[[list[DetectorAnalyzeResult]], Coroutine[Any, list[DetectorAnalyzeResult], Any]]
 
 
-class DetectorKafkaConnector:
+class DetectorKafkaConnector(AsyncInitable, AsyncDeinitable):
     @dataclass(kw_only=True)
     class Config:
         detector_task_topic: str
@@ -83,6 +84,8 @@ class DetectorKafkaConnector:
                                                                            self.DetectorAnalyzeDeserializer()))
             ),
             record_callback=self._process_task_result_kafka_records)
+        AsyncInitable.__init__(self)
+        AsyncDeinitable.__init__(self)
 
     async def create_analyze_task(self, stream_url: str, snapshot_id: str) -> None:
         payload = {
